@@ -367,6 +367,25 @@ extern syslog(int, const char *, ...);
 extern closelog(void);
 #endif
 
+#ifdef RELIANTUNIX
+#define O_RSYNC		0
+#undef HAVE_SNPRINTF
+#undef HAVE_VSNPRINTF
+#define HAVE_GETRUSAGE
+#define PID_T_IS_LONG_INT
+#define SOCKLEN_T       size_t
+#define PATH_TMP        "/tmp"
+#define PATH_VAR_TMP    "/var/tmp"
+#define PATH_PASSWD     "/etc/passwd"
+#define PATH_WTMP       "/var/adm/wtmpx"
+#define PATH_UTMP       "/var/adm/utmpx"
+#define PATH_SYSLOG     "/var/adm/log/messages"
+#ifdef S_ISSOCK
+#undef S_ISSOCK
+#define       S_ISSOCK        S_ISFIFO
+#endif
+#endif
+
 #ifndef RANDSAVENAME
 #define RANDSAVENAME	"/etc/prngd-seed"
 #endif
